@@ -23,6 +23,7 @@
  */
 
 #include <gtk/gtk.h>
+#include "libgmlib/gmlib.h"
 
 #ifdef GIO_ENABLED
 #include <gio/gio.h>
@@ -56,6 +57,10 @@
 #define SUBTITLESCALE	"subtitlescale"
 #define SUBTITLECODEPAGE	"subtitlecodepage"
 #define SUBTITLECOLOR	"subtitlecolor"
+#define SUBTITLEOUTLINE "subtitleoutline"
+#define SUBTITLESHADOW "subtitleshadow"
+#define TRACKER_POSITION "tracker_position"
+
 #define VOLUME	"volume"
 #define USE_MEDIAKEYS		"use_mediakeys"
 #define DISABLE_COVER_ART_FETCH "disable_cover_art_fetch"
@@ -63,12 +68,14 @@
 
 #define MPLAYER_BIN		"mplayer_bin"
 #define EXTRAOPTS		"extraopts"
+#define USE_PULSE_FLAT_VOLUME "use_pulse_flat_volume"
 
-#define DISABLE_QT		"/apps/gecko-mediaplayer/preferences/disable_qt"
-#define DISABLE_REAL	"/apps/gecko-mediaplayer/preferences/disable_real"
-#define DISABLE_WMP		"/apps/gecko-mediaplayer/preferences/disable_wmp"
-#define DISABLE_DVX		"/apps/gecko-mediaplayer/preferences/disable_dvx"
-#define DISABLE_EMBEDDING		"/apps/gecko-mediaplayer/preferences/disable_embedding"
+#define DISABLE_QT		"disable_qt"
+#define DISABLE_REAL	"disable_real"
+#define DISABLE_WMP		"disable_wmp"
+#define DISABLE_DVX		"disable_dvx"
+#define DISABLE_MIDI    "disable_midi"
+#define DISABLE_EMBEDDING		"disable_embedding"
 
 #define REMEMBER_LOC		"remember_loc"
 #define WINDOW_X		"window_x"
@@ -81,6 +88,7 @@
 #define REPLACE_AND_PLAY "replace_and_play"
 #define SHOW_NOTIFICATION "show_notification"
 #define SHOW_STATUS_ICON "show_status_icon"
+#define SHOW_SUBTITLES "show_subtitles"
 
 // JavaScript Playstates
 #define STATE_UNDEFINED     0
@@ -108,7 +116,7 @@ typedef enum {
     NO_ERROR,
     ERROR_RETRY_WITH_PLAYLIST,
     ERROR_RETRY_WITH_HTTP,
-	ERROR_RETRY_WITH_MMSHTTP
+    ERROR_RETRY_WITH_MMSHTTP
 } PLAYBACK_ERROR;
 
 PLAYSTATE state;
@@ -122,6 +130,8 @@ typedef struct _IdleData {
     gchar media_info[2048];
     gchar media_notification[2048];
     gchar url[1024];
+    gchar af_export[1024];
+    GMappedFile *mapped_af_export;
     gint windowid;
     gchar *device;
     gdouble percent;
@@ -210,6 +220,7 @@ enum {
 };
 
 typedef struct _MetaData {
+    gchar *uri;
     gchar *title;
     gchar *artist;
     gchar *album;
@@ -228,6 +239,17 @@ typedef struct _LangMenu {
     int value;
 } LangMenu;
 
+typedef struct _Export {
+    int nch;
+    int size;
+    unsigned long long counter;
+    gint16 payload[7][512];
+} Export;
+
+#define METER_BARS 		44
+gint buckets[METER_BARS];
+gint max_buckets[METER_BARS];
+
 //Define MIME for DnD
 #define DRAG_NAME_0		"text/plain"
 #define DRAG_INFO_0		0
@@ -298,13 +320,17 @@ gboolean disable_ass;
 gboolean disable_embeddedfonts;
 gboolean disable_animation;
 gint auto_hide_timeout;
+gboolean always_hide_after_timeout;
 gchar *subtitlefont;
 gdouble subtitle_scale;
 gchar *subtitle_codepage;
 gchar *subtitle_color;
+gboolean subtitle_outline;
+gboolean subtitle_shadow;
 gboolean quit_on_complete;
 gchar *mplayer_bin;
 gchar *extraopts;
+gboolean use_pulse_flat_volume;
 gboolean single_instance;
 gboolean new_instance;
 gboolean replace_and_play;
@@ -314,6 +340,10 @@ gboolean show_status_icon;
 gboolean load_tracks_from_gpod;
 gchar *gpod_mount_point;
 gboolean disable_cover_art_fetch;
+gboolean updating_recent;
+gint thumb_position;
+gboolean large_buttons;
+gint button_size;
 
 gboolean remember_loc;
 gint loc_window_x;
@@ -322,6 +352,7 @@ gint loc_window_height;
 gint loc_window_width;
 gboolean keep_on_top;
 
+gboolean cancel_folder_load;
 // tv stuff
 gchar *tv_device;
 gchar *tv_driver;
@@ -335,13 +366,19 @@ GMutex *slide_away;
 GCond *mplayer_complete_cond;
 
 gboolean use_mediakeys;
+gboolean dvdnav_title_is_menu;
 
 gboolean qt_disabled;
 gboolean real_disabled;
 gboolean wmp_disabled;
 gboolean dvx_disabled;
+gboolean midi_disabled;
 gboolean embedding_disabled;
 
+GArray *data;
+GArray *max_data;
+gboolean reading_af_export;
+
 // playlist stuff
 GtkListStore *playliststore;
 GtkListStore *nonrandomplayliststore;
@@ -349,7 +386,12 @@ GtkTreeIter iter;
 GtkTreeSelection *selection;
 GtkWidget *list;
 
+// preference store
+GmPrefStore *gm_store;
+GmPrefStore *gmp_store;
+
 GtkWidget *create_window(gint windowid);
+void show_window(gint windowid);
 gint get_player_window();
 void adjust_paned_rules();
 void reset_paned_rules();
@@ -400,6 +442,8 @@ void dbus_unhook();
 void dbus_enable_screensaver();
 void dbus_disable_screensaver();
 
+gboolean update_audio_meter(gpointer data);
+
 void mplayer_shutdown();
 gpointer launch_player(gpointer data);
 
@@ -408,6 +452,7 @@ gboolean read_mplayer_config();
 
 #ifdef GTK2_12_ENABLED
 GtkRecentManager *recent_manager;
+void recent_manager_changed_callback(GtkRecentManager * recent_manager, gpointer data);
 #endif
 
 #endif                          /* _COMMON_H */
