@@ -22,9 +22,12 @@
  * 	Boston, MA  02110-1301, USA.
  */
 //#include <X11/Xlib.h>
+
 #include <gtk/gtk.h>
 #include <gdk/gdk.h>
-//#include <gdk/gdkx.h>
+#include <gdk/gdkx.h>
+#include "libgmlib/gmlib.h"
+#include "libgmtk/gmtk.h"
 #include <gdk/gdkkeysyms.h>
 #include <glib.h>
 #include <glib/gstdio.h>
@@ -35,9 +38,9 @@
 #endif
 
 #include "playlist.h"
-
 GtkWidget *window;
 GdkWindow *window_container;
+GtkWidget *fs_window;
 
 GtkWidget *menubar;
 GtkMenuItem *menuitem_file;
@@ -88,6 +91,7 @@ GtkMenu *menu_view;
 GtkMenuItem *menuitem_view_playlist;
 GtkMenuItem *menuitem_view_info;
 GtkMenuItem *menuitem_view_details;
+GtkMenuItem *menuitem_view_meter;
 GtkMenuItem *menuitem_view_sep0;
 GtkMenuItem *menuitem_view_fullscreen;
 GtkMenuItem *menuitem_view_sep1;
@@ -101,8 +105,12 @@ GtkMenuItem *menuitem_view_aspect_default;
 GtkMenuItem *menuitem_view_aspect_four_three;
 GtkMenuItem *menuitem_view_aspect_sixteen_nine;
 GtkMenuItem *menuitem_view_aspect_sixteen_ten;
+GtkMenuItem *menuitem_view_aspect_follow_window;
 GtkMenuItem *menuitem_view_sep2;
 GtkMenuItem *menuitem_view_subtitles;
+GtkMenuItem *menuitem_view_smaller_subtitle;
+GtkMenuItem *menuitem_view_larger_subtitle;
+GtkMenuItem *menuitem_view_sep5;
 GtkMenuItem *menuitem_view_angle;
 GtkMenuItem *menuitem_view_controls;
 GtkMenuItem *menuitem_view_sep3;
@@ -141,6 +149,8 @@ GtkWidget *media_label;
 GtkWidget *cover_art;
 GtkWidget *details_vbox;
 GtkWidget *details_table;
+GtkWidget *audio_meter;
+
 
 GtkWidget *drawing_area;
 GdkPixbuf *pb_play;
@@ -174,7 +184,8 @@ GtkWidget *next_event_box;
 GtkWidget *menu_event_box;
 
 GtkWidget *fs_event_box;
-GtkProgressBar *progress;
+//GtkProgressBar *progress;
+GmtkMediaTracker *tracker;
 GtkWidget *vol_slider;
 
 gboolean in_button;
@@ -218,6 +229,7 @@ GtkWidget *config_softvol;
 GtkWidget *config_forcecache;
 GtkWidget *config_verbose;
 GtkWidget *config_show_notification;
+GtkWidget *config_thumb_position;
 
 GtkWidget *config_alang;
 GtkWidget *config_slang;
@@ -229,11 +241,15 @@ GtkWidget *config_subtitle_font;
 GtkWidget *config_subtitle_scale;
 GtkWidget *config_subtitle_codepage;
 GtkWidget *config_subtitle_color;
+GtkWidget *config_subtitle_outline;
+GtkWidget *config_subtitle_shadow;
+GtkWidget *config_show_subtitles;
 
 GtkWidget *config_qt;
 GtkWidget *config_real;
 GtkWidget *config_wmp;
 GtkWidget *config_dvx;
+GtkWidget *config_midi;
 GtkWidget *config_noembed;
 
 GtkWidget *config_mplayer_bin;
@@ -288,12 +304,14 @@ void menuitem_fs_callback(GtkMenuItem * menuitem, void *data);
 void menuitem_showcontrols_callback(GtkCheckMenuItem * menuitem, void *data);
 void menuitem_quit_callback(GtkMenuItem * menuitem, void *data);
 void menuitem_details_callback(GtkMenuItem * menuitem, void *data);
-
+void clear_playlist(GtkWidget * widget, void *data);
 gboolean playlist_drop_callback(GtkWidget * widget, GdkDragContext * dc,
                                 gint x, gint y, GtkSelectionData * selection_data,
                                 guint info, guint t, gpointer data);
-
 void create_folder_progress_window();
 void destroy_folder_progress_window();
 void update_status_icon();
 void setup_accelerators();
+
+gint get_height();
+gint get_width();
