@@ -115,6 +115,12 @@ static GOptionEntry entries[] = {
     {"replace_and_play", 0, 0, G_OPTION_ARG_NONE, &replace_and_play,
      N_("Put single instance mode into replace and play mode"),
      NULL},
+    {"large_buttons", 0, 0, G_OPTION_ARG_NONE, &large_buttons,
+     N_("Use large control buttons"),
+     NULL},
+    {"always_hide_after_timeout", 0, 0, G_OPTION_ARG_NONE, &always_hide_after_timeout,
+     N_("Hide control panel when mouse is not moving"),
+     NULL},
     {"new_instance", 0, 0, G_OPTION_ARG_NONE, &new_instance,
      N_("Ignore single instance preference for this instance"),
      NULL},
@@ -152,13 +158,17 @@ gint play_iter(GtkTreeIter * playiter)
     gchar *demuxer = NULL;
     gint width;
     gint height;
+    gint i;
     gpointer pixbuf;
     gchar *buffer = NULL;
     gchar *message = NULL;
     MetaData *metadata;
 #ifdef GTK2_12_ENABLED
     GtkRecentData *recent_data;
-    GtkRecentInfo *recent_info;
+#ifdef GIO_ENABLED
+    GFile *file;
+    GFileInfo *file_info;
+#endif
 #endif
 
     if (gtk_list_store_iter_is_valid(playliststore, playiter)) {
@@ -204,6 +214,12 @@ gint play_iter(GtkTreeIter * playiter)
     }
     reset_paned_rules();
 
+    // reset audio meter
+    for (i = 0; i < METER_BARS; i++) {
+        buckets[i] = 0;
+        max_buckets[i] = 0;
+    }
+
     message = g_strdup_printf("<small>\n");
     if (title == NULL) {
         title = g_filename_display_basename(uri);
@@ -232,6 +248,7 @@ gint play_iter(GtkTreeIter * playiter)
     if (pixbuf == NULL && video_codec == NULL && !streaming_media(uri) && control_id == 0
         && !playlist) {
         metadata = (MetaData *) g_new0(MetaData, 1);
+        metadata->uri = g_strdup(uri);
         if (title != NULL)
             metadata->title = g_strstrip(g_strdup(title));
         if (artist != NULL)
@@ -247,6 +264,10 @@ gint play_iter(GtkTreeIter * playiter)
     g_strlcpy(idledata->display_name, title, 1024);
     g_free(message);
 
+    message = gm_tempname(NULL, "mplayer-af_exportXXXXXX");
+    g_strlcpy(idledata->af_export, message, 1024);
+    g_free(message);
+
     message = g_strdup("");
     if (title == NULL) {
         title = g_filename_display_basename(uri);
@@ -295,7 +316,9 @@ gint play_iter(GtkTreeIter * playiter)
         g_free(subtitle);
     }
 #ifdef HAVE_ASOUNDLIB
-    if (!softvol && ao != NULL && g_ascii_strcasecmp(ao, "alsa") == 0) {
+    if (!softvol && ao != NULL
+        && (g_ascii_strcasecmp(ao, "alsa") == 0
+            || (use_pulse_flat_volume && g_ascii_strcasecmp(ao, "pulse") == 0))) {
         volume = (gint) get_alsa_volume();
         idledata->volume = volume;
 #if GTK2_12_ENABLED
@@ -326,32 +349,42 @@ gint play_iter(GtkTreeIter * playiter)
         }
     }
 #ifdef GTK2_12_ENABLED
+#ifdef GIO_ENABLED
     // don't put it on the recent list, if it is running in plugin mode
-    if (control_id == 0) {
-        gtk_recent_manager_add_item(recent_manager, uri);
-
-        recent_info = gtk_recent_manager_lookup_item(recent_manager, uri, NULL);
-
-        if (recent_info != NULL) {
-            recent_data = (GtkRecentData *) g_new0(GtkRecentData, 1);
-            if (artist != NULL && strlen(artist) > 0) {
-                recent_data->display_name = g_strdup_printf("%s - %s", artist, title);
-            } else {
-                recent_data->display_name = g_strdup(title);
-            }
-            g_strlcpy(idledata->display_name, recent_data->display_name, 1024);
-            recent_data->mime_type = g_strdup(gtk_recent_info_get_mime_type(recent_info));
-            recent_data->app_name = g_strdup("gnome-mplayer");
-            recent_data->app_exec = g_strdup("gnome-mplayer %u");
-            gtk_recent_info_unref(recent_info);
-            gtk_recent_manager_remove_item(recent_manager, uri, NULL);
-            gtk_recent_manager_add_full(recent_manager, uri, recent_data);
-            g_free(recent_data->mime_type);
-            g_free(recent_data->app_name);
-            g_free(recent_data->app_exec);
-            g_free(recent_data);
+    if (control_id == 0 && !streaming_media (uri)) {
+        recent_data = (GtkRecentData *) g_new0(GtkRecentData, 1);
+        if (artist != NULL && strlen(artist) > 0) {
+            recent_data->display_name = g_strdup_printf("%s - %s", artist, title);
+        } else {
+            recent_data->display_name = g_strdup(title);
         }
+        g_strlcpy(idledata->display_name, recent_data->display_name, 1024);
+
+
+        file = g_file_new_for_uri(uri);
+        file_info = g_file_query_info(file,
+                                      G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE ","
+                                      G_FILE_ATTRIBUTE_STANDARD_DISPLAY_NAME,
+                                      G_FILE_QUERY_INFO_NONE, NULL, NULL);
+
+
+        if (file_info) {
+            recent_data->mime_type = g_strdup(g_file_info_get_content_type(file_info));
+            g_object_unref(file_info);
+        }
+        g_object_unref(file);
+        recent_data->app_name = g_strdup("gnome-mplayer");
+        recent_data->app_exec = g_strdup("gnome-mplayer %u");
+		if (recent_data->mime_type != NULL) {
+	        gtk_recent_manager_add_full(recent_manager, uri, recent_data);
+	        g_free(recent_data->mime_type);
+		}
+        g_free(recent_data->app_name);
+        g_free(recent_data->app_exec);
+        g_free(recent_data);
+
     }
+#endif
 #endif
     g_free(title);
     g_free(artist);
@@ -414,11 +447,12 @@ gint play_iter(GtkTreeIter * playiter)
         idledata->windowid = get_player_window();
         // these next 3 lines are here to make sure the window is available for mplayer to draw to
         // for some vo's (like xv) if the window is not visible and big enough the vo setup fails
-        if (thread_data->streaming) {
+        if (thread_data->streaming || thread_data->playlist) {
             idledata->videopresent = 1;
             gtk_widget_set_size_request(drawing_area, 16, 16);
             gtk_widget_show_all(fixed);
         }
+
         if (g_ascii_strcasecmp(uri, "dvdnav://") == 0) {
             gtk_widget_show(menu_event_box);
         } else {
@@ -534,6 +568,8 @@ int main(int argc, char *argv[])
     subtitlefont = NULL;
     subtitle_codepage = NULL;
     subtitle_color = NULL;
+    subtitle_outline = FALSE;
+    subtitle_shadow = FALSE;
     quit_on_complete = FALSE;
     slide_away = NULL;
     verbose = 0;
@@ -561,6 +597,15 @@ int main(int argc, char *argv[])
     fullscreen = 0;
     ao = NULL;
     vo = NULL;
+    use_pulse_flat_volume = FALSE;
+    dvdnav_title_is_menu = FALSE;
+    thumb_position = 3;
+    data = NULL;
+    max_data = NULL;
+    details_table = NULL;
+    large_buttons = FALSE;
+    button_size = 16;
+    lastguistate = -1;
 
     sa.sa_handler = hup_handler;
     sigemptyset(&sa.sa_mask);
@@ -576,63 +621,84 @@ int main(int argc, char *argv[])
     // call g_type_init or otherwise we can crash
     g_type_init();
 
-    init_preference_store();
-    mixer = read_preference_string(MIXER);
-    osdlevel = read_preference_int(OSDLEVEL);
-    pplevel = read_preference_int(PPLEVEL);
+    uri = g_strdup_printf("%s/gnome-mplayer/cover_art", g_get_user_config_dir());
+    if (!g_file_test(uri, G_FILE_TEST_IS_DIR)) {
+        g_mkdir_with_parents(uri, 0775);
+    }
+    g_free(uri);
+
+    uri = g_strdup_printf("%s/gnome-mplayer/plugin", g_get_user_config_dir());
+    if (!g_file_test(uri, G_FILE_TEST_IS_DIR)) {
+        g_mkdir_with_parents(uri, 0775);
+    }
+    g_free(uri);
+    uri = NULL;
+
+    gm_store = gm_pref_store_new("gnome-mplayer");
+    gmp_store = gm_pref_store_new("gecko-mediaplayer");
+    mixer = gm_pref_store_get_string(gm_store, MIXER);
+    osdlevel = gm_pref_store_get_int(gm_store, OSDLEVEL);
+    pplevel = gm_pref_store_get_int(gm_store, PPLEVEL);
 #ifndef HAVE_ASOUNDLIB
-    volume = read_preference_int(VOLUME);
+    volume = gm_pref_store_get_int(gm_store, VOLUME);
 #endif
-    fullscreen = read_preference_bool(FULLSCREEN);
-    softvol = read_preference_bool(SOFTVOL);
-    forcecache = read_preference_bool(FORCECACHE);
-    vertical_layout = read_preference_bool(VERTICAL);
-    playlist_visible = read_preference_bool(SHOWPLAYLIST);
-    details_visible = read_preference_bool(SHOWDETAILS);
-    show_notification = read_preference_bool(SHOW_NOTIFICATION);
-    show_status_icon = read_preference_bool(SHOW_STATUS_ICON);
-    disable_deinterlace = read_preference_bool(DISABLEDEINTERLACE);
-    disable_framedrop = read_preference_bool(DISABLEFRAMEDROP);
-    disable_fullscreen = read_preference_bool(DISABLEFULLSCREEN);
-    disable_context_menu = read_preference_bool(DISABLECONTEXTMENU);
-    disable_ass = read_preference_bool(DISABLEASS);
-    disable_embeddedfonts = read_preference_bool(DISABLEEMBEDDEDFONTS);
-    disable_pause_on_click = read_preference_bool(DISABLEPAUSEONCLICK);
-    disable_animation = read_preference_bool(DISABLEANIMATION);
-    auto_hide_timeout = read_preference_int(AUTOHIDETIMEOUT);
-    disable_cover_art_fetch = read_preference_bool(DISABLE_COVER_ART_FETCH);
-    use_mediakeys = read_preference_bool(USE_MEDIAKEYS);
-    metadata_codepage = read_preference_string(METADATACODEPAGE);
-    subtitlefont = read_preference_string(SUBTITLEFONT);
-    subtitle_scale = read_preference_float(SUBTITLESCALE);
+    fullscreen = gm_pref_store_get_boolean(gm_store, FULLSCREEN);
+    softvol = gm_pref_store_get_boolean(gm_store, SOFTVOL);
+    forcecache = gm_pref_store_get_boolean(gm_store, FORCECACHE);
+    vertical_layout = gm_pref_store_get_boolean(gm_store, VERTICAL);
+    playlist_visible = gm_pref_store_get_boolean(gm_store, SHOWPLAYLIST);
+    details_visible = gm_pref_store_get_boolean(gm_store, SHOWDETAILS);
+    show_notification = gm_pref_store_get_boolean(gm_store, SHOW_NOTIFICATION);
+    show_status_icon = gm_pref_store_get_boolean(gm_store, SHOW_STATUS_ICON);
+    disable_deinterlace = gm_pref_store_get_boolean(gm_store, DISABLEDEINTERLACE);
+    disable_framedrop = gm_pref_store_get_boolean(gm_store, DISABLEFRAMEDROP);
+    disable_fullscreen = gm_pref_store_get_boolean(gm_store, DISABLEFULLSCREEN);
+    disable_context_menu = gm_pref_store_get_boolean(gm_store, DISABLECONTEXTMENU);
+    disable_ass = gm_pref_store_get_boolean(gm_store, DISABLEASS);
+    disable_embeddedfonts = gm_pref_store_get_boolean(gm_store, DISABLEEMBEDDEDFONTS);
+    disable_pause_on_click = gm_pref_store_get_boolean(gm_store, DISABLEPAUSEONCLICK);
+    disable_animation = gm_pref_store_get_boolean(gm_store, DISABLEANIMATION);
+    auto_hide_timeout =
+        gm_pref_store_get_int_with_default(gm_store, AUTOHIDETIMEOUT, auto_hide_timeout);
+    disable_cover_art_fetch = gm_pref_store_get_boolean(gm_store, DISABLE_COVER_ART_FETCH);
+    use_mediakeys = gm_pref_store_get_boolean(gm_store, USE_MEDIAKEYS);
+    metadata_codepage = gm_pref_store_get_string(gm_store, METADATACODEPAGE);
+    subtitlefont = gm_pref_store_get_string(gm_store, SUBTITLEFONT);
+    subtitle_scale = gm_pref_store_get_float(gm_store, SUBTITLESCALE);
     if (subtitle_scale < 0.25) {
         subtitle_scale = 1.0;
     }
-    subtitle_codepage = read_preference_string(SUBTITLECODEPAGE);
-    subtitle_color = read_preference_string(SUBTITLECOLOR);
+    subtitle_codepage = gm_pref_store_get_string(gm_store, SUBTITLECODEPAGE);
+    subtitle_color = gm_pref_store_get_string(gm_store, SUBTITLECOLOR);
+    subtitle_outline = gm_pref_store_get_boolean(gm_store, SUBTITLEOUTLINE);
+    subtitle_shadow = gm_pref_store_get_boolean(gm_store, SUBTITLESHADOW);
+    showsubtitles = gm_pref_store_get_boolean_with_default(gm_store, SHOW_SUBTITLES, TRUE);
 
-    qt_disabled = read_preference_bool(DISABLE_QT);
-    real_disabled = read_preference_bool(DISABLE_REAL);
-    wmp_disabled = read_preference_bool(DISABLE_WMP);
-    dvx_disabled = read_preference_bool(DISABLE_DVX);
-    embedding_disabled = read_preference_bool(DISABLE_EMBEDDING);
-    single_instance = read_preference_bool(SINGLE_INSTANCE);
+    qt_disabled = gm_pref_store_get_boolean(gmp_store, DISABLE_QT);
+    real_disabled = gm_pref_store_get_boolean(gmp_store, DISABLE_REAL);
+    wmp_disabled = gm_pref_store_get_boolean(gmp_store, DISABLE_WMP);
+    dvx_disabled = gm_pref_store_get_boolean(gmp_store, DISABLE_DVX);
+    midi_disabled = gm_pref_store_get_boolean(gmp_store, DISABLE_MIDI);
+    embedding_disabled = gm_pref_store_get_boolean(gmp_store, DISABLE_EMBEDDING);
+    single_instance = gm_pref_store_get_boolean(gm_store, SINGLE_INSTANCE);
     if (single_instance)
-        replace_and_play = read_preference_bool(REPLACE_AND_PLAY);
+        replace_and_play = gm_pref_store_get_boolean(gm_store, REPLACE_AND_PLAY);
 
-    mplayer_bin = read_preference_string(MPLAYER_BIN);
+    mplayer_bin = gm_pref_store_get_string(gm_store, MPLAYER_BIN);
     if (mplayer_bin != NULL && !g_file_test(mplayer_bin, G_FILE_TEST_EXISTS)) {
         g_free(mplayer_bin);
         mplayer_bin = NULL;
     }
-    extraopts = read_preference_string(EXTRAOPTS);
+    extraopts = gm_pref_store_get_string(gm_store, EXTRAOPTS);
+    use_pulse_flat_volume = gm_pref_store_get_boolean(gm_store, USE_PULSE_FLAT_VOLUME);
+    thumb_position = gm_pref_store_get_int_with_default(gm_store, TRACKER_POSITION, thumb_position);
 
-    remember_loc = read_preference_bool(REMEMBER_LOC);
-    loc_window_x = read_preference_int(WINDOW_X);
-    loc_window_y = read_preference_int(WINDOW_Y);
-    loc_window_height = read_preference_int(WINDOW_HEIGHT);
-    loc_window_width = read_preference_int(WINDOW_WIDTH);
-    keep_on_top = read_preference_bool(KEEP_ON_TOP);
+    remember_loc = gm_pref_store_get_boolean(gm_store, REMEMBER_LOC);
+    loc_window_x = gm_pref_store_get_int(gm_store, WINDOW_X);
+    loc_window_y = gm_pref_store_get_int(gm_store, WINDOW_Y);
+    loc_window_height = gm_pref_store_get_int(gm_store, WINDOW_HEIGHT);
+    loc_window_width = gm_pref_store_get_int(gm_store, WINDOW_WIDTH);
+    keep_on_top = gm_pref_store_get_boolean(gm_store, KEEP_ON_TOP);
     read_mplayer_config();
 
     context = g_option_context_new(_("[FILES...] - GNOME Media player based on MPlayer"));
@@ -649,7 +715,7 @@ int main(int argc, char *argv[])
         single_instance = FALSE;
 
     if (verbose == 0)
-        verbose = read_preference_int(VERBOSE);
+        verbose = gm_pref_store_get_int(gm_store, VERBOSE);
 
     if (reallyverbose)
         verbose = 2;
@@ -658,10 +724,12 @@ int main(int argc, char *argv[])
         printf(_("GNOME MPlayer v%s\n"), VERSION);
 
     if (cache_size == 0)
-        cache_size = read_preference_int(CACHE_SIZE);
+        cache_size = gm_pref_store_get_int(gm_store, CACHE_SIZE);
     if (cache_size == 0)
         cache_size = 2000;
-    release_preference_store();
+    gm_pref_store_free(gm_store);
+    gm_pref_store_free(gmp_store);
+
     read_mplayer_config();
 
     if (verbose && single_instance) {
@@ -675,6 +743,15 @@ int main(int argc, char *argv[])
 
     if (volume == -1) {
         volume = (gint) get_alsa_volume();
+		if (!use_pulse_flat_volume) {
+		    if (ao != NULL && g_ascii_strncasecmp(ao, "pulse", strlen("pulse")) == 0) {
+		        if (verbose)
+		            printf
+		                ("Using pulse audio, setting volume to max (will be limited by mixer 100%% of %i%%)\n",
+		                 volume);
+		        volume = 100;
+		    }
+		}		
     } else {
         if (verbose)
             printf("Using volume of %i from gnome-mplayer preference\n", volume);
@@ -688,20 +765,15 @@ int main(int argc, char *argv[])
         volume = 100;
     }
 
-    if (ao != NULL && g_ascii_strncasecmp(ao, "pulse", strlen("pulse")) == 0) {
-        if (verbose)
-            printf
-                ("Using pulse audio, setting volume to max (will be limited by mixer 100%% of %i%%)\n",
-                 volume);
-        volume = 100;
-    }
-
-    if (volume > 0 && volume <= 100) {
+    if (volume >= 0 && volume <= 100) {
         idledata->volume = (gdouble) volume;
     }
 
     use_volume_option = detect_volume_option();
 
+    if (large_buttons)
+        button_size = 48;
+
     if (playlist_visible && control_id != 0)
         playlist_visible = FALSE;
 
@@ -758,7 +830,7 @@ int main(int argc, char *argv[])
             printf("is reg %i\n", S_ISREG(buf.st_mode));
             printf("is dir %i\n", S_ISDIR(buf.st_mode));
             printf("playlist %i\n", playlist);
-            printf("embedded in window id %i\n", embed_window);
+            printf("embedded in window id 0x%x\n", embed_window);
         }
         if (S_ISBLK(buf.st_mode)) {
             // might have a block device, so could be a DVD
@@ -879,12 +951,7 @@ int main(int argc, char *argv[])
             }
         }
 
-    } else {
-        if (embed_window == 0) {
-            gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menuitem_view_playlist),
-                                           playlist_visible);
-        }
-    }
+    } 
 
 #ifdef HAVE_GPOD
     if (load_tracks_from_gpod) {
@@ -901,7 +968,10 @@ int main(int argc, char *argv[])
     gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menuitem_view_details), details_visible);
 
     dbus_hookup(embed_window, control_id);
-
+    show_window(embed_window);
+	if (argv[fileindex] == NULL && embed_window == 0) {
+        gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menuitem_view_playlist), playlist_visible);
+    }	
     gtk_main();
 
     return 0;
