@@ -260,9 +260,9 @@ void save_playlist(GtkWidget * widget, void *data)
     gtk_file_chooser_set_local_only(GTK_FILE_CHOOSER(dialog), FALSE);
 #endif
     gtk_widget_show(dialog);
-    init_preference_store();
-    last_dir = read_preference_string(LAST_DIR);
-    if (last_dir != NULL)
+    gm_store = gm_pref_store_new("gnome-mplayer");
+    last_dir = gm_pref_store_get_string(gm_store, LAST_DIR);
+    if (last_dir != NULL && is_uri_dir(last_dir))
         gtk_file_chooser_set_current_folder_uri(GTK_FILE_CHOOSER(dialog), last_dir);
 
     gtk_file_chooser_set_do_overwrite_confirmation(GTK_FILE_CHOOSER(dialog), TRUE);
@@ -280,7 +280,7 @@ void save_playlist(GtkWidget * widget, void *data)
 
         uri = gtk_file_chooser_get_uri(GTK_FILE_CHOOSER(dialog));
         last_dir = gtk_file_chooser_get_current_folder_uri(GTK_FILE_CHOOSER(dialog));
-        write_preference_string(LAST_DIR, last_dir);
+        gm_pref_store_set_string(gm_store, LAST_DIR, last_dir);
         g_free(last_dir);
 
         if (g_strrstr(uri, ".m3u") != NULL) {
@@ -297,7 +297,7 @@ void save_playlist(GtkWidget * widget, void *data)
         }
         g_free(uri);
     }
-    release_preference_store();
+    gm_pref_store_free(gm_store);
     gtk_widget_destroy(dialog);
 
 }
@@ -315,9 +315,9 @@ void load_playlist(GtkWidget * widget, void *data)
                                          GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                                          GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT, NULL);
     gtk_widget_show(dialog);
-    init_preference_store();
-    last_dir = read_preference_string(LAST_DIR);
-    if (last_dir != NULL)
+    gm_store = gm_pref_store_new("gnome-mplayer");
+    last_dir = gm_pref_store_get_string(gm_store, LAST_DIR);
+    if (last_dir != NULL && is_uri_dir(last_dir))
         gtk_file_chooser_set_current_folder_uri(GTK_FILE_CHOOSER(dialog), last_dir);
 
     filter = gtk_file_filter_new();
@@ -339,7 +339,7 @@ void load_playlist(GtkWidget * widget, void *data)
 
         filename = gtk_file_chooser_get_uri(GTK_FILE_CHOOSER(dialog));
         last_dir = gtk_file_chooser_get_current_folder_uri(GTK_FILE_CHOOSER(dialog));
-        write_preference_string(LAST_DIR, last_dir);
+        gm_pref_store_set_string(gm_store, LAST_DIR, last_dir);
         g_free(last_dir);
 
         gtk_list_store_clear(playliststore);
@@ -351,7 +351,7 @@ void load_playlist(GtkWidget * widget, void *data)
         }
         destroy_folder_progress_window();
     }
-    release_preference_store();
+    gm_pref_store_free(gm_store);
     update_gui();
     gtk_widget_destroy(dialog);
 }
@@ -410,10 +410,14 @@ void add_folder_to_playlist_callback(gpointer data, gpointer user_data)
                 filecount++;
             }
             g_object_unref(info);
-            info = g_file_enumerator_next_file(dir, NULL, NULL);
+            info = NULL;
+            if (!cancel_folder_load)
+                info = g_file_enumerator_next_file(dir, NULL, NULL);
+
         }
         list = g_slist_sort(list, (GCompareFunc) compar);
-        g_slist_foreach(list, &add_item_to_playlist_callback, NULL);
+        if (!cancel_folder_load)
+            g_slist_foreach(list, &add_item_to_playlist_callback, NULL);
         g_slist_free(list);
         g_object_unref(dir);
     }
@@ -447,9 +451,12 @@ void add_folder_to_playlist_callback(gpointer data, gpointer user_data)
             } else {
                 break;
             }
+            if (cancel_folder_load)
+                break;
         } while (TRUE);
         list = g_slist_sort(list, (GCompareFunc) compar);
-        g_slist_foreach(list, &add_item_to_playlist_callback, NULL);
+        if (!cancel_folder_load)
+            g_slist_foreach(list, &add_item_to_playlist_callback, NULL);
         g_slist_free(list);
         g_dir_close(dir);
     }
@@ -479,9 +486,9 @@ void add_to_playlist(GtkWidget * widget, void *data)
     gtk_file_chooser_set_local_only(GTK_FILE_CHOOSER(dialog), FALSE);
 #endif
 
-    init_preference_store();
-    last_dir = read_preference_string(LAST_DIR);
-    if (last_dir != NULL) {
+    gm_store = gm_pref_store_new("gnome-mplayer");
+    last_dir = gm_pref_store_get_string(gm_store, LAST_DIR);
+    if (last_dir != NULL && is_uri_dir(last_dir)) {
         gtk_file_chooser_set_current_folder_uri(GTK_FILE_CHOOSER(dialog), last_dir);
         g_free(last_dir);
     }
@@ -492,14 +499,14 @@ void add_to_playlist(GtkWidget * widget, void *data)
         uris = gtk_file_chooser_get_uris(GTK_FILE_CHOOSER(dialog));
 
         last_dir = gtk_file_chooser_get_current_folder_uri(GTK_FILE_CHOOSER(dialog));
-        write_preference_string(LAST_DIR, last_dir);
+        gm_pref_store_set_string(gm_store, LAST_DIR, last_dir);
         g_free(last_dir);
 
         g_slist_foreach(uris, &add_item_to_playlist_callback, NULL);
         g_slist_free(uris);
     }
     update_gui();
-    release_preference_store();
+    gm_pref_store_free(gm_store);
     column = gtk_tree_view_get_column(GTK_TREE_VIEW(list), 0);
     if (playlistname != NULL && strlen(playlistname) > 0 && count == 0) {
         coltitle = g_strdup_printf(_("%s items"), playlistname);
@@ -533,9 +540,9 @@ void add_folder_to_playlist(GtkWidget * widget, void *data)
     gtk_file_chooser_set_local_only(GTK_FILE_CHOOSER(dialog), FALSE);
 #endif
 
-    init_preference_store();
-    last_dir = read_preference_string(LAST_DIR);
-    if (last_dir != NULL) {
+    gm_store = gm_pref_store_new("gnome-mplayer");
+    last_dir = gm_pref_store_get_string(gm_store, LAST_DIR);
+    if (last_dir != NULL && is_uri_dir(last_dir)) {
         gtk_file_chooser_set_current_folder_uri(GTK_FILE_CHOOSER(dialog), last_dir);
         g_free(last_dir);
     }
@@ -545,7 +552,7 @@ void add_folder_to_playlist(GtkWidget * widget, void *data)
         uris = gtk_file_chooser_get_uris(GTK_FILE_CHOOSER(dialog));
 
         last_dir = gtk_file_chooser_get_current_folder_uri(GTK_FILE_CHOOSER(dialog));
-        write_preference_string(LAST_DIR, last_dir);
+        gm_pref_store_set_string(gm_store, LAST_DIR, last_dir);
         g_free(last_dir);
 
         filecount = 0;
@@ -555,7 +562,7 @@ void add_folder_to_playlist(GtkWidget * widget, void *data)
         g_slist_free(uris);
     }
     update_gui();
-    release_preference_store();
+    gm_pref_store_free(gm_store);
     gtk_widget_destroy(dialog);
     message =
         g_markup_printf_escaped(ngettext("\n\tFound %i file\n", "\n\tFound %i files\n", filecount),
@@ -753,14 +760,12 @@ void menuitem_view_playlist_callback(GtkMenuItem * menuitem, void *data)
     if (gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(menuitem_view_playlist)) == FALSE) {
         if (GTK_WIDGET_VISIBLE(plvbox)) {
             if (idledata->videopresent == FALSE) {
-                gdk_window_get_geometry(window->window, &x, &y, &window_width, &window_height,
-                                        &depth);
-                stored_window_width = -1;
-                stored_window_height = -1;
+                window_width = -1;
+                window_height = -1;
+                gtk_window_get_size(GTK_WINDOW(window), &window_width, &window_height);
                 gtk_window_set_resizable(GTK_WINDOW(window), FALSE);
                 gtk_widget_hide(GTK_WIDGET(fixed));
                 gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menuitem_view_info), TRUE);
-                gtk_widget_show(vbox);
                 gtk_widget_set_size_request(window, -1, -1);
             } else {
                 gtk_widget_style_get(pane, "handle-size", &handle_size, NULL);
@@ -791,26 +796,20 @@ void menuitem_view_playlist_callback(GtkMenuItem * menuitem, void *data)
     } else {
         gtk_window_set_resizable(GTK_WINDOW(window), TRUE);
         if (idledata->videopresent == FALSE) {
-            if (window_width != -1)
-                gtk_window_resize(GTK_WINDOW(window), window_width, window_height);
+            if (!gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(menuitem_view_info))) {
+                gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menuitem_view_info), TRUE);
+            }
+        }
+        if (restore_playlist) {
             if (vertical_layout) {
-                gtk_widget_hide(fixed);
+                stored_window_height = restore_pane;
             } else {
-                gtk_widget_hide(vbox);
+                stored_window_width = restore_pane;
             }
+            restore_playlist = FALSE;
         } else {
-            // set the window size properly when coming out of fullscreen mode.
-            if (restore_playlist) {
-                if (vertical_layout) {
-                    stored_window_height = restore_pane;
-                } else {
-                    stored_window_width = restore_pane;
-                }
-                restore_playlist = FALSE;
-            } else {
-                gdk_window_get_geometry(window->window, &x, &y, &stored_window_width,
-                                        &stored_window_height, &depth);
-            }
+            gdk_window_get_geometry(window->window, &x, &y, &stored_window_width,
+                                    &stored_window_height, &depth);
         }
         plvbox = gtk_vbox_new(FALSE, 12);
         hbox = gtk_hbox_new(FALSE, 12);
@@ -820,7 +819,7 @@ void menuitem_view_playlist_callback(GtkMenuItem * menuitem, void *data)
         closebox = gtk_hbox_new(FALSE, 0);
 
         list = gtk_tree_view_new_with_model(GTK_TREE_MODEL(playliststore));
-        gtk_tree_view_set_reorderable(GTK_TREE_VIEW(list), TRUE);
+        gtk_tree_view_set_reorderable(GTK_TREE_VIEW(list), FALSE);
         gtk_widget_add_events(list, GDK_BUTTON_PRESS_MASK);
         gtk_widget_set_size_request(GTK_WIDGET(list), -1, -1);
 
@@ -1020,20 +1019,15 @@ void menuitem_view_playlist_callback(GtkMenuItem * menuitem, void *data)
         gtk_widget_style_get(pane, "handle-size", &handle_size, NULL);
         if (vertical_layout) {
             gtk_widget_set_size_request(plvbox, -1, 150);
-            if (idledata->videopresent)
-                gtk_window_resize(GTK_WINDOW(window), stored_window_width,
-                                  stored_window_height + 150 + handle_size);
+            gtk_window_resize(GTK_WINDOW(window), stored_window_width,
+                              stored_window_height + 150 + handle_size);
         } else {
             gtk_widget_set_size_request(plvbox, 300, -1);
-            if (idledata->videopresent) {
-                gtk_window_resize(GTK_WINDOW(window), stored_window_width + 300 + handle_size,
-                                  stored_window_height);
-            }
+            gtk_window_resize(GTK_WINDOW(window), stored_window_width + 300 + handle_size,
+                              stored_window_height);
         }
         gtk_widget_show_all(plvbox);
-        if (idledata->videopresent == FALSE) {
-            gtk_widget_show(GTK_WIDGET(fixed));
-        } else {
+        if (idledata->videopresent) {
             gtk_window_set_policy(GTK_WINDOW(window), TRUE, TRUE, TRUE);
         }
 
