@@ -69,6 +69,8 @@ gint detect_playlist(gchar * uri)
         playlist = 1;
     } else if (g_strncasecmp(uri, "dvd://", 6) == 0) {
         playlist = 1;
+    } else if (g_strncasecmp(uri, "vcd://", 6) == 0) {
+        playlist = 1;
 //      } else if (g_strncasecmp(filename,"dvdnav://",9) == 0) {
 //              playlist = 1;
     } else if (device_name(uri)) {
@@ -251,6 +253,8 @@ gint parse_playlist(gchar * uri)
         ret = parse_cdda(uri);
     if (ret != 1)
         ret = parse_dvd(uri);
+    if (ret != 1)
+        ret = parse_vcd(uri);
     if (ret == 1 && count == 0) {
         if (playlistname != NULL) {
             g_free(playlistname);
@@ -369,7 +373,6 @@ gint parse_basic(gchar * uri)
                 }
                 g_strfreev(parse);
             }
-
             if (g_ascii_strncasecmp(newline, "[playlist]", strlen("[playlist]")) == 0) {
                 //printf("playlist\n");
                 //continue;
@@ -383,7 +386,16 @@ gint parse_basic(gchar * uri)
                 g_free(newline);
                 break;
             } else if (g_strncasecmp(newline, "<smil", strlen("<smil")) == 0) {
+                //printf("smil\n");
+                g_free(newline);
+                break;
+            } else if (g_strrstr(newline, "<asx") != NULL) {
                 //printf("asx\n");
+                idledata->streaming = TRUE;
+                g_free(newline);
+                break;
+            } else if (g_strrstr(newline, "<smil") != NULL) {
+                //printf("smil\n");
                 g_free(newline);
                 break;
             } else if (g_strncasecmp(newline, "numberofentries", strlen("numberofentries")) == 0) {
@@ -393,7 +405,7 @@ gint parse_basic(gchar * uri)
                 //printf("ver\n");
                 //continue;
             } else if (g_strncasecmp(newline, "title", strlen("title")) == 0) {
-                //printf("tit\n");
+                //printf("title\n");
                 //continue;
             } else if (g_strncasecmp(newline, "length", strlen("length")) == 0) {
                 //printf("len\n");
@@ -761,6 +773,97 @@ gint parse_dvd(gchar * filename)
     return ret;
 }
 
+// This function pulls the playlist for dvd and dvdnav
+gint parse_vcd(gchar * filename)
+{
+
+    GError *error;
+    gint exit_status;
+    gchar *out;
+    gchar *err;
+    gchar *av[255];
+    gint ac = 0, i;
+    gint ret = 0;
+    gchar **output;
+    gchar *track;
+    gint num;
+    gchar *error_msg = NULL;
+    GtkWidget *dialog;
+
+    if (g_strncasecmp(filename, "vcd://", strlen("vcd://")) == 0) {
+        playlist = 0;
+
+        if (mplayer_bin == NULL || !g_file_test(mplayer_bin, G_FILE_TEST_EXISTS)) {
+            av[ac++] = g_strdup_printf("mplayer");
+        } else {
+            av[ac++] = g_strdup_printf("%s", mplayer_bin);
+        }
+        av[ac++] = g_strdup_printf("-vo");
+        av[ac++] = g_strdup_printf("null");
+        av[ac++] = g_strdup_printf("-ao");
+        av[ac++] = g_strdup_printf("null");
+        av[ac++] = g_strdup_printf("-frames");
+        av[ac++] = g_strdup_printf("0");
+        av[ac++] = g_strdup_printf("-identify");
+        if (idledata->device != NULL) {
+            av[ac++] = g_strdup_printf("-dvd-device");
+            av[ac++] = g_strdup_printf("%s", idledata->device);
+        }
+        av[ac++] = g_strdup_printf("vcd://");
+        av[ac] = NULL;
+
+        error = NULL;
+
+        g_spawn_sync(NULL, av, NULL, G_SPAWN_SEARCH_PATH, NULL, NULL, &out, &err,
+                     &exit_status, &error);
+        for (i = 0; i < ac; i++) {
+            g_free(av[i]);
+        }
+        if (error != NULL) {
+            printf("Error when running: %s\n", error->message);
+            g_error_free(error);
+            if (out != NULL)
+                g_free(out);
+            if (err != NULL)
+                g_free(err);
+            error = NULL;
+        }
+        output = g_strsplit(out, "\n", 0);
+        if (strstr(err, "Couldn't open VCD device:") != NULL) {
+            error_msg =
+                g_strdup_printf(_("Couldn't open VCD device: %s"),
+                                err + strlen("Couldn't open VCD device: "));
+        }
+        ac = 0;
+        while (output[ac] != NULL) {
+            if (g_strncasecmp(output[ac], "ID_VCD_TRACK_", strlen("ID_VCD_TRACK_")) == 0) {
+                sscanf(output[ac], "ID_VCD_TRACK_%i", &num);
+                track = g_strdup_printf("vcd://%i", num);
+                printf("adding track %s\n", track);
+                add_item_to_playlist(track, 0);
+                g_free(track);
+            }
+            ac++;
+        }
+        g_strfreev(output);
+
+        if (error_msg != NULL) {
+            dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR,
+                                            GTK_BUTTONS_CLOSE, error_msg);
+            gtk_window_set_title(GTK_WINDOW(dialog), _("GNOME MPlayer Error"));
+            gtk_dialog_run(GTK_DIALOG(dialog));
+            gtk_widget_destroy(dialog);
+            g_free(error_msg);
+            ret = 0;
+        } else {
+            ret = 1;
+        }
+    } else {
+        return 0;
+    }
+
+    return ret;
+}
 
 gboolean update_mplayer_config()
 {
@@ -956,9 +1059,16 @@ gboolean streaming_media(gchar * uri)
 #ifdef GIO_ENABLED
         file = g_file_new_for_uri(uri);
         if (file != NULL) {
-            info = g_file_query_info(file, "access::*", G_FILE_QUERY_INFO_NONE, NULL, NULL);
+            info = g_file_query_info(file, "*", G_FILE_QUERY_INFO_NONE, NULL, NULL);
             if (info != NULL) {
-                ret = !g_file_info_get_attribute_boolean(info, G_FILE_ATTRIBUTE_ACCESS_CAN_READ);
+                // SMB filesystems seem to give incorrect access answers over GIO, 
+                // so if the file has a filesize > 0 we think it is not streaming
+                if (g_ascii_strncasecmp(uri, "smb://", strlen("smb://")) == 0) {
+                    ret = (g_file_info_get_size(info) > 0) ? FALSE : TRUE;
+                } else {
+                    ret =
+                        !g_file_info_get_attribute_boolean(info, G_FILE_ATTRIBUTE_ACCESS_CAN_READ);
+                }
                 g_object_unref(info);
             } else {
                 ret = !g_file_test(uri, G_FILE_TEST_EXISTS);
@@ -1232,6 +1342,11 @@ MetaData *get_metadata(gchar * uri)
         title = g_strdup_printf("%s", localtitle);
     }
 
+    if (title == NULL && g_strncasecmp(name, "vcd://", strlen("vcd://")) == 0) {
+        localtitle = g_strrstr(name, "/") + 1;
+        title = g_strdup_printf("%s", localtitle);
+    }
+
     if (title == NULL && g_strncasecmp(name, "dvdnav://", strlen("dvdnav://")) == 0) {
         title = g_strdup_printf("DVD");
     }
@@ -1425,13 +1540,16 @@ gint get_bitrate(gchar * name)
 gboolean add_item_to_playlist(const gchar * uri, gint playlist)
 {
     GtkTreeIter localiter;
-	gchar *local_uri;
+    gchar *local_uri;
     gchar *unescaped = NULL;
     MetaData *data = NULL;
 
+    if (strlen(uri) < 1)
+        return FALSE;
+
     if (verbose)
-        printf("adding %s to playlist\n", uri);
-	local_uri = strdup(uri);
+        printf("adding %s to playlist (cancel = %i)\n", uri, cancel_folder_load);
+    local_uri = strdup(uri);
     if (!device_name(local_uri) && !streaming_media(local_uri)) {
         if (playlist) {
             data = (MetaData *) g_new0(MetaData, 1);
@@ -1451,7 +1569,7 @@ gboolean add_item_to_playlist(const gchar * uri, gint playlist)
     } else {
 
         if (g_str_has_prefix(uri, "http://")) {
-            unescaped = switch_protocol(uri,"mmshttp");
+            unescaped = switch_protocol(uri, "mmshttp");
             g_free(local_uri);
             local_uri = g_strdup(unescaped);
             g_free(unescaped);
@@ -1508,10 +1626,10 @@ gboolean add_item_to_playlist(const gchar * uri, gint playlist)
         g_free(data->audio_codec);
         g_free(data->video_codec);
         g_free(data);
-		g_free(local_uri);
+        g_free(local_uri);
         return TRUE;
     } else {
-		g_free(local_uri);
+        g_free(local_uri);
         return FALSE;
     }
 
@@ -1965,7 +2083,7 @@ gdouble get_alsa_volume()
 
 gchar *seconds_to_string(gfloat seconds)
 {
-    int hour = 0, min = 0;
+    int hour = 0, min = 0, sec = 0;
     gchar *result = NULL;
 
     if (seconds >= 3600) {
@@ -1976,219 +2094,16 @@ gchar *seconds_to_string(gfloat seconds)
         min = seconds / 60;
         seconds = seconds - (min * 60);
     }
+    sec = seconds;
 
     if (hour == 0) {
-        result = g_strdup_printf(_("%2i:%02.0f"), min, seconds);
+        result = g_strdup_printf(_("%2i:%02i"), min, sec);
     } else {
-        result = g_strdup_printf(_("%i:%02i:%02.0f"), hour, min, seconds);
+        result = g_strdup_printf(_("%i:%02i:%02i"), hour, min, sec);
     }
     return result;
 }
 
-void init_preference_store()
-{
-    gchar *filename;
-
-    filename = g_strdup_printf("%s/gnome-mplayer/cover_art", g_get_user_cache_dir());
-    if (!g_file_test(filename, G_FILE_TEST_IS_DIR)) {
-        g_mkdir_with_parents(filename, 0775);
-    }
-    g_free(filename);
-    filename = g_strdup_printf("%s/gnome-mplayer/plugin", g_get_user_cache_dir());
-    if (!g_file_test(filename, G_FILE_TEST_IS_DIR)) {
-        g_mkdir_with_parents(filename, 0775);
-    }
-    g_free(filename);
-
-#ifdef HAVE_GCONF
-    gconf = gconf_client_get_default();
-#else
-    filename = g_strdup_printf("%s/gnome-mplayer", g_get_user_config_dir());
-    if (!g_file_test(filename, G_FILE_TEST_IS_DIR)) {
-        g_mkdir_with_parents(filename, 0775);
-    }
-    g_free(filename);
-
-    config = g_key_file_new();
-    filename = g_strdup_printf("%s/gnome-mplayer/gnome-mplayer.conf", g_get_user_config_dir());
-    g_key_file_load_from_file(config,
-                              filename,
-                              G_KEY_FILE_KEEP_COMMENTS | G_KEY_FILE_KEEP_TRANSLATIONS, NULL);
-
-#endif
-
-}
-
-gboolean read_preference_bool(gchar * key)
-{
-    gboolean value = FALSE;
-#ifdef HAVE_GCONF
-    gchar *full_key = NULL;
-
-    if (strstr(key, "/")) {
-        full_key = g_strdup_printf("%s", key);
-    } else {
-        full_key = g_strdup_printf("/apps/gnome-mplayer/preferences/%s", key);
-    }
-    value = gconf_client_get_bool(gconf, full_key, NULL);
-    g_free(full_key);
-#else
-    gchar *short_key;
-
-    if (strstr(key, "/")) {
-        short_key = g_strrstr(key, "/") + sizeof(gchar);
-    } else {
-        short_key = g_strdup_printf("%s", key);
-    }
-
-    value = g_key_file_get_boolean(config, "gnome-mplayer", short_key, NULL);
-#endif
-    return value;
-}
-
-gint read_preference_int(gchar * key)
-{
-    gint value = 0;
-#ifdef HAVE_GCONF
-    gchar *full_key = NULL;
-
-    full_key = g_strdup_printf("/apps/gnome-mplayer/preferences/%s", key);
-    value = gconf_client_get_int(gconf, full_key, NULL);
-    g_free(full_key);
-#else
-    value = g_key_file_get_integer(config, "gnome-mplayer", key, NULL);
-#endif
-    return value;
-}
-
-gfloat read_preference_float(gchar * key)
-{
-    gfloat value = 0;
-#ifdef HAVE_GCONF
-    gchar *full_key = NULL;
-
-    full_key = g_strdup_printf("/apps/gnome-mplayer/preferences/%s", key);
-    value = gconf_client_get_float(gconf, full_key, NULL);
-    g_free(full_key);
-#else
-    value = g_key_file_get_double(config, "gnome-mplayer", key, NULL);
-#endif
-    return value;
-}
-
-gchar *read_preference_string(gchar * key)
-{
-    gchar *value = NULL;
-#ifdef HAVE_GCONF
-    gchar *full_key = NULL;
-
-    if (strstr(key, "/")) {
-        full_key = g_strdup_printf("%s", key);
-    } else {
-        full_key = g_strdup_printf("/apps/gnome-mplayer/preferences/%s", key);
-    }
-    value = gconf_client_get_string(gconf, full_key, NULL);
-    g_free(full_key);
-#else
-    value = g_key_file_get_string(config, "gnome-mplayer", key, NULL);
-#endif
-
-    return value;
-}
-
-void write_preference_bool(gchar * key, gboolean value)
-{
-#ifdef HAVE_GCONF
-    gchar *full_key = NULL;
-
-
-    if (strstr(key, "/")) {
-        full_key = g_strdup_printf("%s", key);
-    } else {
-        full_key = g_strdup_printf("/apps/gnome-mplayer/preferences/%s", key);
-    }
-    gconf_client_set_bool(gconf, full_key, value, NULL);
-    g_free(full_key);
-#else
-    gchar *short_key;
-
-    if (strstr(key, "/")) {
-        short_key = g_strrstr(key, "/") + sizeof(gchar);
-    } else {
-        short_key = g_strdup_printf("%s", key);
-    }
-    g_key_file_set_boolean(config, "gnome-mplayer", short_key, value);
-#endif
-}
-
-void write_preference_int(gchar * key, gint value)
-{
-#ifdef HAVE_GCONF
-    gchar *full_key = NULL;
-
-    full_key = g_strdup_printf("/apps/gnome-mplayer/preferences/%s", key);
-    gconf_client_set_int(gconf, full_key, value, NULL);
-    g_free(full_key);
-#else
-    g_key_file_set_integer(config, "gnome-mplayer", key, value);
-#endif
-}
-
-void write_preference_float(gchar * key, gfloat value)
-{
-#ifdef HAVE_GCONF
-    gchar *full_key = NULL;
-
-    full_key = g_strdup_printf("/apps/gnome-mplayer/preferences/%s", key);
-    gconf_client_set_float(gconf, full_key, value, NULL);
-    g_free(full_key);
-#else
-    g_key_file_set_double(config, "gnome-mplayer", key, value);
-#endif
-}
-
-void write_preference_string(gchar * key, gchar * value)
-{
-#ifdef HAVE_GCONF
-    gchar *full_key = NULL;
-
-    full_key = g_strdup_printf("/apps/gnome-mplayer/preferences/%s", key);
-    gconf_client_unset(gconf, full_key, NULL);
-    if (value != NULL && strlen(g_strstrip(value)) > 0)
-        gconf_client_set_string(gconf, full_key, value, NULL);
-    g_free(full_key);
-#else
-    if (value != NULL && strlen(g_strstrip(value)) > 0) {
-        g_key_file_set_string(config, "gnome-mplayer", key, value);
-    } else {
-        g_key_file_remove_key(config, "gnome-mplayer", key, NULL);
-    }
-#endif
-}
-
-
-void release_preference_store()
-{
-#ifdef HAVE_GCONF
-    if (G_IS_OBJECT(gconf))
-        g_object_unref(G_OBJECT(gconf));
-#else
-    gchar *filename;
-    gchar *data;
-
-    if (config != NULL) {
-        filename = g_strdup_printf("%s/gnome-mplayer/gnome-mplayer.conf", g_get_user_config_dir());
-        data = g_key_file_to_data(config, NULL, NULL);
-
-        g_file_set_contents(filename, data, -1, NULL);
-        g_free(data);
-        g_free(filename);
-        g_key_file_free(config);
-        config = NULL;
-    }
-#endif
-}
-
 #ifdef GIO_ENABLED
 void cache_callback(goffset current_num_bytes, goffset total_num_bytes, gpointer data)
 {
@@ -2220,7 +2135,6 @@ gchar *get_localfile_from_uri(gchar * uri)
         return g_strdup(uri);
     }
     localfile = g_filename_from_uri(uri, NULL, NULL);
-
 #ifdef GIO_ENABLED
     idledata->tmpfile = FALSE;
     if (localfile == NULL) {
@@ -2362,7 +2276,7 @@ gboolean gpod_load_tracks(gchar * mount_point)
     Itdb_Thumb *thumb;
 #endif
     GList *tracks;
-    gint i = 0;
+    gint i = 0, width, height;
     gchar *duration;
     gchar *ipod_path;
     gchar *full_path;
@@ -2379,7 +2293,7 @@ gboolean gpod_load_tracks(gchar * mount_point)
             while (g_strrstr(ipod_path, ":")) {
                 ipod_path[g_strrstr(ipod_path, ":") - ipod_path] = '/';
             }
-            full_path = g_strdup_printf("file:///%s%s", mount_point, ipod_path);
+            full_path = g_strdup_printf("file://%s%s", mount_point, ipod_path);
             g_free(ipod_path);
 
             artwork = (Itdb_Artwork *) ((Itdb_Track *) (tracks->data))->artwork;
@@ -2399,6 +2313,16 @@ gboolean gpod_load_tracks(gchar * mount_point)
                 //printf("%s has a thumbnail\n", ((Itdb_Track *) (tracks->data))->title);
             }
 #endif
+            // printf("%s is movie = %i\n",((Itdb_Track *) (tracks->data))->title,((Itdb_Track *) (tracks->data))->movie_flag);
+
+            if (((Itdb_Track *) (tracks->data))->movie_flag) {
+                width = 640;
+                height = 480;
+            } else {
+                width = 0;
+                height = 0;
+            }
+
             gtk_list_store_append(playliststore, &localiter);
             gtk_list_store_set(playliststore, &localiter, ITEM_COLUMN, full_path,
                                DESCRIPTION_COLUMN, ((Itdb_Track *) (tracks->data))->title,
@@ -2406,6 +2330,8 @@ gboolean gpod_load_tracks(gchar * mount_point)
                                PLAYLIST_COLUMN, 0,
                                ARTIST_COLUMN, ((Itdb_Track *) (tracks->data))->artist,
                                ALBUM_COLUMN, ((Itdb_Track *) (tracks->data))->album,
+                               VIDEO_WIDTH_COLUMN, width,
+                               VIDEO_HEIGHT_COLUMN, height,
                                SUBTITLE_COLUMN, NULL, LENGTH_COLUMN, duration, COVERART_COLUMN,
                                pixbuf, -1);
 
@@ -2416,6 +2342,8 @@ gboolean gpod_load_tracks(gchar * mount_point)
                                PLAYLIST_COLUMN, 0,
                                ARTIST_COLUMN, ((Itdb_Track *) (tracks->data))->artist,
                                ALBUM_COLUMN, ((Itdb_Track *) (tracks->data))->album,
+                               VIDEO_WIDTH_COLUMN, width,
+                               VIDEO_HEIGHT_COLUMN, height,
                                SUBTITLE_COLUMN, NULL, LENGTH_COLUMN, duration, COVERART_COLUMN,
                                pixbuf, -1);
 
@@ -2430,7 +2358,7 @@ gboolean gpod_load_tracks(gchar * mount_point)
         if (i > 1) {
             gtk_widget_set_sensitive(GTK_WIDGET(menuitem_edit_random), TRUE);
             gtk_widget_set_sensitive(GTK_WIDGET(menuitem_edit_loop), TRUE);
-            gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menuitem_view_playlist), TRUE);
+            // gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menuitem_view_playlist), TRUE);
         }
         return TRUE;
     } else {
@@ -2525,9 +2453,9 @@ gchar *get_cover_art_url(gchar * artist, gchar * title, gchar * album)
 gpointer get_cover_art(gpointer data)
 {
     gchar *url;
-    gchar *path;
-    gchar *p;
-    gchar *cache_file;
+    gchar *path = NULL;
+    gchar *p = NULL;
+    gchar *cache_file = NULL;
     gboolean local_artist = FALSE;
     gboolean local_album = FALSE;
     CURL *curl;
@@ -2535,6 +2463,9 @@ gpointer get_cover_art(gpointer data)
     gpointer pixbuf;
     MetaData *metadata = (MetaData *) data;
     gboolean art_found = TRUE;
+#ifdef GIO_ENABLED
+    GFile *file;
+#endif
 
     if (metadata->artist == NULL || strlen(metadata->artist) == 0) {
         if (metadata->artist)
@@ -2549,12 +2480,59 @@ gpointer get_cover_art(gpointer data)
         local_album = TRUE;
     }
 
-    path =
-        g_strdup_printf("%s/gnome-mplayer/cover_art/%s", g_get_user_cache_dir(), metadata->artist);
+    path = g_strdup(metadata->uri);
+    p = g_strrstr(path, "/");
+    if (p != NULL) {
+        p[0] = '\0';
+        p = g_strconcat(path, "/cover.jpg", NULL);
+#ifdef GIO_ENABLED
+        file = g_file_new_for_uri(p);
+        cache_file = g_file_get_path(file);
+        g_object_unref(file);
+#else
+        cache_file = g_filename_from_uri(p, NULL, NULL);
+#endif
+        g_free(p);
+        if (verbose)
+            printf("Looking for cover art at %s\n", cache_file);
+
+    }
+    g_free(path);
+    path = NULL;
+    p = NULL;
+
+    if (cache_file == NULL || !g_file_test(cache_file, G_FILE_TEST_EXISTS)) {
+        path = g_strdup(metadata->uri);
+        p = g_strrstr(path, "/");
+        if (p != NULL) {
+            p[0] = '\0';
+            p = g_strconcat(path, "/Folder.jpg", NULL);
+#ifdef GIO_ENABLED
+            file = g_file_new_for_uri(p);
+            cache_file = g_file_get_path(file);
+            g_object_unref(file);
+#else
+            cache_file = g_filename_from_uri(p, NULL, NULL);
+#endif
+            g_free(p);
+            if (verbose)
+                printf("Looking for cover art at %s\n", cache_file);
+        }
+        g_free(path);
+        path = NULL;
+        p = NULL;
+    }
+
+    if (cache_file == NULL || !g_file_test(cache_file, G_FILE_TEST_EXISTS)) {
+        path =
+            g_strdup_printf("%s/gnome-mplayer/cover_art/%s", g_get_user_cache_dir(),
+                            metadata->artist);
+
+        cache_file =
+            g_strdup_printf("%s/gnome-mplayer/cover_art/%s/%s.jpeg", g_get_user_cache_dir(),
+                            metadata->artist, metadata->album);
+    }
 
-    cache_file =
-        g_strdup_printf("%s/gnome-mplayer/cover_art/%s/%s.jpeg", g_get_user_cache_dir(),
-                        metadata->artist, metadata->album);
     if (local_artist) {
         g_free(metadata->artist);
         metadata->artist = NULL;
@@ -2651,6 +2629,7 @@ gpointer get_cover_art(gpointer data)
     g_free(cache_file);
     g_free(path);
 
+    g_free(metadata->uri);
     g_free(metadata->title);
     g_free(metadata->artist);
     g_free(metadata->album);
@@ -2664,6 +2643,7 @@ gpointer get_cover_art(gpointer data)
 
     if (verbose)
         printf("libcurl required for cover art retrieval\n");
+    g_free(metadata->uri);
     g_free(metadata->title);
     g_free(metadata->artist);
     g_free(metadata->album);
@@ -2679,34 +2659,6 @@ gchar *get_cover_art_url(gchar * artist, gchar * title, gchar * album)
 }
 #endif
 
-gchar *gmp_tempname(gchar * path, const gchar * name_template)
-{
-    gchar *result;
-    gchar *replace;
-    gchar *basename;
-    gchar *localpath;
-
-    basename = g_strdup(name_template);
-
-    if (path == NULL && g_getenv("TMPDIR") == NULL) {
-        localpath = g_strdup("/tmp");
-    } else if (path == NULL && g_getenv("TMPDIR") != NULL) {
-        localpath = g_strdup(g_getenv("TMPDIR"));
-    } else {
-        localpath = g_strdup(path);
-    }
-
-    while ((replace = g_strrstr(basename, "X"))) {
-        replace[0] = (gchar) g_random_int_range((gint) 'a', (gint) 'z');
-    }
-
-    result = g_strdup_printf("%s/%s", localpath, basename);
-    g_free(basename);
-    g_free(localpath);
-
-    return result;
-}
-
 
 /* 
 	older mplayer binaries do not have the -volume option
@@ -2770,13 +2722,45 @@ gboolean detect_volume_option()
     return ret;
 }
 
-gchar *switch_protocol(const gchar *uri, gchar *new_protocol) {
-	gchar *p;
-	
-	p = g_strrstr(uri,"://");
-	
-	if (p != NULL)
-		return g_strdup_printf("%s%s",new_protocol,p);
-	else
-		return NULL;
+gchar *switch_protocol(const gchar * uri, gchar * new_protocol)
+{
+    gchar *p;
+
+    p = g_strrstr(uri, "://");
+
+    if (p != NULL)
+        return g_strdup_printf("%s%s", new_protocol, p);
+    else
+        return NULL;
+}
+
+gboolean map_af_export_file(gpointer data)
+{
+    IdleData *idle = (IdleData *) data;
+
+    if (reading_af_export)
+        return TRUE;
+
+    if (data != NULL) {
+        idle->mapped_af_export = g_mapped_file_new((gchar *) idle->af_export, FALSE, NULL);
+    }
+    return FALSE;
+}
+
+gboolean unmap_af_export_file(gpointer data)
+{
+    IdleData *idle = (IdleData *) data;
+
+    if (reading_af_export)
+        return TRUE;
+
+    if (idle->mapped_af_export) {
+        g_mapped_file_free(idle->mapped_af_export);
+        idle->mapped_af_export = NULL;
+        g_unlink((gchar *) idle->af_export);
+    }
+
+    gmtk_audio_meter_set_data(GMTK_AUDIO_METER(audio_meter), NULL);
+
+    return FALSE;
 }
