@@ -34,15 +34,6 @@
 #include <asoundlib.h>
 #endif
 
-#ifdef HAVE_GCONF
-#include <gconf/gconf.h>
-#include <gconf/gconf-client.h>
-#include <gconf/gconf-value.h>
-GConfClient *gconf;
-#else
-GKeyFile *config;
-#endif
-
 #ifdef GIO_ENABLED
 #include <gio/gio.h>
 #endif
@@ -70,6 +61,7 @@ gint parse_basic(gchar * filename);
 gint parse_ram(gchar * filename);
 gint parse_cdda(gchar * filename);
 gint parse_dvd(gchar * filename);
+gint parse_vcd(gchar * filename);
 gboolean save_playlist_pls(gchar * filename);
 gboolean save_playlist_m3u(gchar * filename);
 gchar *get_path(gchar * filename);
@@ -84,21 +76,10 @@ void randomize_playlist(GtkListStore * store);
 gdouble get_alsa_volume();
 gchar *seconds_to_string(gfloat seconds);
 
-void init_preference_store();
-gboolean read_preference_bool(gchar * key);
-gint read_preference_int(gchar * key);
-gfloat read_preference_float(gchar * key);
-gchar *read_preference_string(gchar * key);
-void write_preference_bool(gchar * key, gboolean value);
-void write_preference_int(gchar * key, gint value);
-void write_preference_float(gchar * key, gfloat value);
-void write_preference_string(gchar * key, gchar * value);
-void release_preference_store();
-
 gchar *get_localfile_from_uri(gchar * uri);
 gboolean is_uri_dir(gchar * uri);
 gboolean uri_exists(gchar * uri);
-gchar *switch_protocol(const gchar *uri, gchar *new_protocol);
+gchar *switch_protocol(const gchar * uri, gchar * new_protocol);
 
 #ifdef HAVE_GPOD
 gchar *find_gpod_mount_point();
@@ -108,7 +89,8 @@ gboolean gpod_load_tracks(gchar * mount_point);
 gchar *get_cover_art_url(gchar * artist, gchar * title, gchar * album);
 gpointer get_cover_art(gpointer data);
 
-gchar *gmp_tempname(gchar * path, const gchar * name_template);
 gboolean detect_volume_option();
+gboolean map_af_export_file(gpointer data);
+gboolean unmap_af_export_file(gpointer data);
 
 #endif                          // _SUPPORT_H
