@@ -32,6 +32,11 @@ void mplayer_shutdown()
         idledata->percent = 1.0;
         g_idle_add(set_progress_value, idledata);
         g_idle_add(set_stop, idledata);
+        if (g_file_test(idledata->af_export, G_FILE_TEST_EXISTS)) {
+            // stop audio export monitor
+            // as part of the stopping, remove file when memmapped file is closed
+            g_idle_add(unmap_af_export_file, idledata);
+        }
         send_command("quit\n", FALSE);
     }
 
@@ -41,6 +46,7 @@ gboolean send_command(gchar * command, gboolean retain_pause)
 {
     gchar *cmd;
     GIOStatus result;
+    gsize bytes_written;
 
     if (retain_pause) {
         if (use_pausing_keep_force) {
@@ -56,7 +62,7 @@ gboolean send_command(gchar * command, gboolean retain_pause)
         printf("send command = %s\n", cmd);
 
     if (channel_in) {
-        result = g_io_channel_write_chars(channel_in, cmd, -1, NULL, NULL);
+        result = g_io_channel_write_chars(channel_in, cmd, -1, &bytes_written, NULL);
         result = g_io_channel_flush(channel_in, NULL);
     }
 
@@ -70,8 +76,8 @@ gboolean play(void *data)
     PlayData *p = (PlayData *) data;
 
     if (ok_to_play && p != NULL) {
-        gtk_list_store_set(playliststore, &iter, PLAYLIST_COLUMN, p->playlist, ITEM_COLUMN,
-                           p->uri);
+        gtk_list_store_set(playliststore, &iter, PLAYLIST_COLUMN, p->playlist, ITEM_COLUMN, p->uri,
+                           -1);
         play_iter(&iter);
     }
     g_free(p);
@@ -147,15 +153,25 @@ gboolean thread_reader_error(GIOChannel * source, GIOCondition condition, gpoint
                 error_msg =
                     g_strdup_printf(_("Failed to open %s"),
                                     mplayer_output->str + strlen("Failed to open "));
-			}
-		
-			if (strstr(mplayer_output->str, "mms://") != NULL && idledata->streaming) {
-				dontplaynext = TRUE;
-				playback_error = ERROR_RETRY_WITH_MMSHTTP;
-			}
+            }
+
+            if (strstr(mplayer_output->str, "mms://") != NULL && idledata->streaming) {
+                dontplaynext = TRUE;
+                playback_error = ERROR_RETRY_WITH_MMSHTTP;
+            }
         }
     }
 
+    if (strstr(mplayer_output->str, "No stream found to handle url mmshttp://") != NULL) {
+        dontplaynext = TRUE;
+        playback_error = ERROR_RETRY_WITH_HTTP;
+    }
+
+	if (strstr(mplayer_output->str, "Error while parsing chunk header") != NULL) {
+        dontplaynext = TRUE;
+        playback_error = ERROR_RETRY_WITH_HTTP;
+    }
+
     if (strstr(mplayer_output->str, "Couldn't open DVD device:") != NULL) {
         error_msg =
             g_strdup_printf(_("Couldn't open DVD device: %s"),
@@ -305,6 +321,10 @@ gboolean thread_reader(GIOChannel * source, GIOCondition condition, gpointer dat
         sscanf(buf, "VO: [%9[^]]] %ix%i => %ix%i", vm, &actual_x, &actual_y, &play_x, &play_y);
 
         if (play_x >= actual_x && play_y >= actual_y) {
+            if (actual_x == last_window_width && actual_y == last_window_height) {
+                last_window_width = 0;
+                last_window_height = 0;
+            }
             actual_x = play_x;
             actual_y = play_y;
         }
@@ -470,7 +490,7 @@ gboolean thread_reader(GIOChannel * source, GIOCondition condition, gpointer dat
         g_strlcpy(idledata->progress_text, buf, 1024);
         g_free(buf);
         g_idle_add(set_progress_text, idledata);
-        idledata->percent = percent / 100.0;
+        idledata->cachepercent = percent / 100.0;
         g_idle_add(set_progress_value, idledata);
     }
 
@@ -582,6 +602,14 @@ gboolean thread_reader(GIOChannel * source, GIOCondition condition, gpointer dat
         g_idle_add(set_update_gui, NULL);
     }
 
+    if (strstr(mplayer_output->str, "DVDNAV_TITLE_IS_MENU") != 0) {
+        dvdnav_title_is_menu = TRUE;
+    }
+
+    if (strstr(mplayer_output->str, "DVDNAV_TITLE_IS_MOVIE") != 0) {
+        dvdnav_title_is_menu = FALSE;
+    }
+
     if (strstr(mplayer_output->str, "Couldn't open DVD device") != 0) {
         error_msg = g_strdup(mplayer_output->str);
     }
@@ -615,6 +643,10 @@ gboolean thread_reader(GIOChannel * source, GIOCondition condition, gpointer dat
             message = g_strdup_printf("<small>\n\t<big><b>%s</b></big>\n</small>", buf + 1);
         }
         if (message) {
+            // reset max values in audio meter
+            for (i = 0; i < METER_BARS; i++) {
+                max_buckets[i] = 0;
+            }
             g_strlcpy(idledata->media_info, message, 1024);
             g_free(message);
             message = g_strdup_printf("\n\t<b>%s</b>\n", buf + 1);
@@ -674,6 +706,13 @@ gboolean thread_query(gpointer data)
         return FALSE;
     }
 
+    if (idledata->mapped_af_export == NULL && g_file_test(idledata->af_export, G_FILE_TEST_EXISTS)) {
+        // start audio export monitor
+        // but don't start polling until meter is visible
+        g_idle_add(map_af_export_file, idledata);
+    }
+
+
     if (state == PLAYING) {
         // size = write(std_in, "get_percent_pos\n", strlen("get_percent_pos\n"));
         size = write(std_in, "get_time_pos\n", strlen("get_time_pos\n"));
@@ -751,12 +790,14 @@ gpointer launch_player(gpointer data)
         argv[arg++] = g_strdup_printf("%s", mplayer_bin);
     }
 
+    // argv[arg++] = g_strdup_printf("-v");
+
     if ((vo != NULL && strlen(vo) > 0) || (ao != NULL && strlen(ao) > 0)) {
         argv[arg++] = g_strdup_printf("-profile");
         argv[arg++] = g_strdup_printf("gnome-mplayer");
     }
 
-    if (vo != NULL && g_ascii_strcasecmp(vo, "xvmc") == 0) {
+    if (vo != NULL && g_ascii_strncasecmp(vo, "xvmc", strlen("xvmc")) == 0) {
         if (g_strncasecmp(threaddata->filename, "dvd://", strlen("dvd://")) == 0
             || g_strncasecmp(threaddata->filename, "dvdnav://", strlen("dvdnav://")) == 0) {
             argv[arg++] = g_strdup_printf("-vc");
@@ -771,7 +812,7 @@ gpointer launch_player(gpointer data)
         }
     }
 
-    if (vo != NULL && g_ascii_strcasecmp(vo, "vdpau") == 0) {
+    if (vo != NULL && g_ascii_strncasecmp(vo, "vdpau", strlen("vdpau")) == 0) {
         //printf("video_codec = '%s'\n",idledata->video_codec);
         if (g_ascii_strcasecmp(idledata->video_codec, "ffmpeg1") == 0
             || g_ascii_strcasecmp(idledata->video_codec, "ffmpeg2") == 0
@@ -822,7 +863,8 @@ gpointer launch_player(gpointer data)
         argv[arg++] = g_strdup_printf("-framedrop");
 
     if (vo == NULL
-        || !(g_ascii_strcasecmp(vo, "xvmc") == 0 || g_ascii_strcasecmp(vo, "vdpau") == 0)) {
+        || !(g_ascii_strncasecmp(vo, "xvmc", strlen("xvmc")) == 0
+             || g_ascii_strncasecmp(vo, "vdpau", strlen("vdpau")) == 0)) {
         if (!disable_deinterlace) {
             argv[arg++] = g_strdup_printf("-vf-pre");
             argv[arg++] = g_strdup_printf("yadif,softskip,scale");
@@ -900,13 +942,25 @@ gpointer launch_player(gpointer data)
             argv[arg++] = g_strdup_printf("-embeddedfonts");
 
         argv[arg++] = g_strdup_printf("-ass-font-scale");
-        argv[arg++] = g_strdup_printf("%1.1f", subtitle_scale);
-        if (subtitlefont != NULL && strlen(subtitlefont) > 0) {
+        argv[arg++] = g_strdup_printf("%1.2f", subtitle_scale);
+        if (disable_embeddedfonts && subtitlefont != NULL && strlen(subtitlefont) > 0) {
             fontname = g_strdup(subtitlefont);
             size = g_strrstr(fontname, " ");
             size[0] = '\0';
+            size = g_strrstr(fontname, " Bold");
+            if (size)
+                size[0] = '\0';
+            size = g_strrstr(fontname, " Italic");
+            if (size)
+                size[0] = '\0';
             argv[arg++] = g_strdup_printf("-ass-force-style");
-            argv[arg++] = g_strdup_printf("FontName=%s", fontname);
+            argv[arg++] = g_strconcat("FontName=", fontname,
+                                      ((g_strrstr(subtitlefont, "Italic") !=
+                                        NULL) ? ",Italic=1" : ",Italic=0"),
+                                      ((g_strrstr(subtitlefont, "Bold") !=
+                                        NULL) ? ",Bold=1" : ",Bold=0"),
+                                      (subtitle_outline ? ",Outline=1" : ",Outline=0"),
+                                      (subtitle_shadow ? ",Shadow=2" : ",Shadow=0"), NULL);
             g_free(fontname);
         }
 
@@ -934,11 +988,15 @@ gpointer launch_player(gpointer data)
         argv[arg++] = g_strdup_printf("%s", subtitle_codepage);
     }
 
-    if (pplevel > 0) {
-        argv[arg++] = g_strdup_printf("-vf-add");
-        argv[arg++] = g_strdup_printf("pp=ac/tn:a");
-        argv[arg++] = g_strdup_printf("-autoq");
-        argv[arg++] = g_strdup_printf("%d", pplevel);
+    if (vo == NULL || !(g_ascii_strncasecmp(vo, "xvmc", strlen("xvmc")) == 0
+                        || g_ascii_strncasecmp(vo, "vdpau", strlen("vdpau")) == 0)) {
+
+        if (pplevel > 0) {
+            argv[arg++] = g_strdup_printf("-vf-add");
+            argv[arg++] = g_strdup_printf("pp=ac/tn:a");
+            argv[arg++] = g_strdup_printf("-autoq");
+            argv[arg++] = g_strdup_printf("%d", pplevel);
+        }
     }
 
     if (extraopts != NULL) {
@@ -950,7 +1008,8 @@ gpointer launch_player(gpointer data)
     }
 
     if (vo == NULL
-        || !(g_ascii_strcasecmp(vo, "xvmc") == 0 || g_ascii_strcasecmp(vo, "vdpau") == 0)) {
+        || !(g_ascii_strncasecmp(vo, "xvmc", strlen("xvmc")) == 0
+             || g_ascii_strncasecmp(vo, "vdpau", strlen("vdpau")) == 0)) {
         argv[arg++] = g_strdup_printf("-vf-add");
         argv[arg++] = g_strdup_printf("screenshot");
     }
@@ -981,6 +1040,10 @@ gpointer launch_player(gpointer data)
 	}		
 	g_free(filename);
 */
+
+    argv[arg++] = g_strdup_printf("-af-add");
+    argv[arg++] = g_strdup_printf("export=%s:512", idledata->af_export);
+
     if (threaddata->playlist)
         argv[arg++] = g_strdup_printf("-playlist");
 
@@ -1061,6 +1124,7 @@ gpointer launch_player(gpointer data)
 #else
         g_timeout_add(1000, thread_query, threaddata);
 #endif
+
         g_cond_wait(mplayer_complete_cond, thread_running);
         if (verbose)
             printf("Thread completing\n");
@@ -1112,15 +1176,21 @@ gpointer launch_player(gpointer data)
         }
 #endif
 
+        if (g_file_test(idledata->af_export, G_FILE_TEST_EXISTS)) {
+            // stop audio export monitor
+            // as part of the stopping, remove file when memmapped file is closed
+            g_idle_add(unmap_af_export_file, idledata);
+        }
+
         dbus_enable_screensaver();
         g_mutex_unlock(thread_running);
-        
-		if (idledata->cachepercent < 0 && g_str_has_prefix(threaddata->filename, "mms")) {
+
+        if (idledata->cachepercent < 0 && g_str_has_prefix(threaddata->filename, "mms")) {
             dontplaynext = TRUE;
             playback_error = ERROR_RETRY_WITH_MMSHTTP;
         }
 
-		if (idledata->cachepercent < 0 && g_str_has_prefix(threaddata->filename, "mmshttp")) {
+        if (idledata->cachepercent < 0 && g_str_has_prefix(threaddata->filename, "mmshttp")) {
             dontplaynext = TRUE;
             playback_error = ERROR_RETRY_WITH_HTTP;
         }
@@ -1171,21 +1241,21 @@ gpointer launch_player(gpointer data)
                 p->playlist = 1;
                 g_idle_add(play, p);
             }
-			
+
             if (playback_error == ERROR_RETRY_WITH_HTTP) {
                 p = (PlayData *) g_malloc(sizeof(PlayData));
-				filename = switch_protocol(threaddata->filename,"http");
+                filename = switch_protocol(threaddata->filename, "http");
                 g_strlcpy(p->uri, filename, 4096);
-				g_free(filename);
+                g_free(filename);
                 p->playlist = threaddata->playlist;
                 g_idle_add(play, p);
             }
 
-			if (playback_error == ERROR_RETRY_WITH_MMSHTTP) {
+            if (playback_error == ERROR_RETRY_WITH_MMSHTTP) {
                 p = (PlayData *) g_malloc(sizeof(PlayData));
-				filename = switch_protocol(threaddata->filename,"mmshttp");
+                filename = switch_protocol(threaddata->filename, "mmshttp");
                 g_strlcpy(p->uri, filename, 4096);
-				g_free(filename);
+                g_free(filename);
                 p->playlist = threaddata->playlist;
                 g_idle_add(play, p);
             }
